from ._scholarly import _Scholarly
from .data_types import Author, Publication
from ._proxy_generator import ProxyGenerator, DOSException, MaxTriesExceededException
scholarly = _Scholarly()
